"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var index_exports = {};
__export(index_exports, {
  renderTemplateWithJS: () => renderTemplateWithJS
});
module.exports = __toCommonJS(index_exports);
function renderTemplateWithJS(template, context, options = {}) {
  const [openDelimiter, closeDelimiter] = options.delimiters || ["{", "}"];
  const escOpenDelimiter = openDelimiter.replace(/[.*+?^${}()|[\]\\]/g, "\\$&");
  const escCloseDelimiter = closeDelimiter.replace(/[.*+?^${}()|[\]\\]/g, "\\$&");
  const expressionRegex = new RegExp(`${escOpenDelimiter}([^${escOpenDelimiter}${escCloseDelimiter}]*?)${escCloseDelimiter}`, "g");
  const singleExpressionRegex = new RegExp(`^${escOpenDelimiter}([\\s\\S]*?)${escCloseDelimiter}$`);
  const mergedContext = {
    ...context,
    ...options.contextExtensions
  };
  if (options.returnRawValues) {
    const trimmedTemplate = template.trim();
    const match = trimmedTemplate.match(singleExpressionRegex);
    if (match) {
      try {
        const expression = match[1].trim();
        const contextKeys = Object.keys(mergedContext);
        const contextValues = Object.values(mergedContext);
        const isIIFE = /^\s*\(.*\)\s*\(.*\)/.test(expression) || // (function(){})() pattern
        /^\s*\(.*=>.*\)\s*\(/.test(expression);
        const hasDeclarations = /\b(const|let|var|function|class)\b/.test(expression);
        const hasMultipleStatements = expression.includes(";");
        let result;
        if (isIIFE) {
          try {
            const contextStr = Object.entries(mergedContext).map(([key, value]) => `const ${key} = ${JSON.stringify(value)};`).join("\n");
            result = eval(`${contextStr}
${expression}`);
          } catch (error) {
            console.error(`Error executing IIFE:`, error);
            return `[Error: ${error instanceof Error ? error.message : String(error)}]`;
          }
        } else if (hasDeclarations || hasMultipleStatements) {
          let functionBody;
          if (expression.includes("return ")) {
            functionBody = expression;
          } else {
            const lastSemicolonIndex = expression.lastIndexOf(";");
            if (lastSemicolonIndex !== -1 && lastSemicolonIndex < expression.length - 1) {
              const lastExpression = expression.substring(lastSemicolonIndex + 1).trim();
              functionBody = `${expression.substring(0, lastSemicolonIndex + 1)} return ${lastExpression};`;
            } else {
              functionBody = `${expression} return undefined;`;
            }
          }
          try {
            const evaluator = new Function(...contextKeys, functionBody);
            result = evaluator(...contextValues);
          } catch (error) {
            console.error(`Error executing complex expression:`, error);
            return `[Error: ${error instanceof Error ? error.message : String(error)}]`;
          }
        } else {
          try {
            const evaluator = new Function(...contextKeys, `return ${expression};`);
            result = evaluator(...contextValues);
          } catch (error) {
            console.error(`Error executing simple expression:`, error);
            return `[Error: ${error instanceof Error ? error.message : String(error)}]`;
          }
        }
        return result;
      } catch (error) {
        console.error(`Error evaluating expression:`, error);
        return `[Error: ${error instanceof Error ? error.message : String(error)}]`;
      }
    }
  }
  return template.replace(expressionRegex, (match2, expression2) => {
    try {
      const contextKeys2 = Object.keys(mergedContext);
      const contextValues2 = Object.values(mergedContext);
      const evaluator = new Function(...contextKeys2, `return (${expression2});`);
      const result2 = evaluator(...contextValues2);
      if (result2 === void 0 || result2 === null) {
        return "";
      }
      return String(result2);
    } catch (error) {
      console.error(`Error evaluating expression "${expression2}":`, error);
      return `[Error: ${error instanceof Error ? error.message : String(error)}]`;
    }
  });
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  renderTemplateWithJS
});
